@@ -1,5 +1,5 @@
 # -*- encoding: utf-8 -*-
-# Python Dist Manager v0.0.7
+# Python Dist Manager v0.0.8
 # "Maximum Overkill DRY" PyPI distribution manager (WiP)
 # Copyright © 2020, Shlomi Fish.
 # All rights reserved.
@@ -40,7 +40,7 @@
 """
 
 __title__ = 'Python Dist Manager'
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 __author__ = 'Shlomi Fish'
 __license__ = '3-clause BSD'
 __docformat__ = 'restructuredtext en'
@@ -99,8 +99,13 @@ class DistManager(object):
         self.dest_modules_dir = self.dest_dir + "/" + dist_name
         system = platform.system().lower()
         self.tox_cmd = (
-            "py -3.9 -m tox"
-            if (('windows' in system) or ('cygwin' in system)) else 'tox')
+            (
+                "py -3.8 -m tox"
+                if os.getenv('APPVEYOR')
+                else "py -3.9 -m tox"
+            ) if (('windows' in system) or ('cygwin' in system))
+            else 'tox'
+        )
 
     def _slurp(self, fn):
         with open(fn, "rt") as ifh:
